==> react-readonly-codemirror6-1.0.0.tgz: package/index.jsx <==
import { EditorView } from '@codemirror/view';
import { lineNumbers } from '@codemirror/gutter';
import { defaultHighlightStyle } from '@codemirror/highlight';
import { EditorState } from '@codemirror/state';
import {
  oneDarkHighlightStyle,
  oneDarkTheme,
} from '@codemirror/theme-one-dark';
// eslint-disable-next-line import/no-unresolved
import { useEffect, useRef } from 'react';
import getLanguageExtension from './src/getLanguageExtension';

function getEditorView(parent) {
  return new EditorView({
    parent: parent.current,
    // lineWrapping: true,
  });
}

function getFontsizeTheme(size = 14) {
  return EditorView.theme({
    '&': {
      fontSize: `${size}px`,
    },
  });
}

function initState({ code, lang, fontSize }) {
  // const lg = langExtension();
  const language = getLanguageExtension(lang);

  return EditorState.create({
    doc: code,
    extensions: [
      lineNumbers(),
      language,
      oneDarkTheme,
      oneDarkHighlightStyle,
      getFontsizeTheme(fontSize),
      defaultHighlightStyle.fallback,
      EditorView.editable.of(false),
    ],
  });
}

const useRocm = ({ code, lang, fontSize }) => {
  const editorParentRef = useRef(null);
  const editorRef = useRef(null);

  // Initilize view
  useEffect(() => {
    if (!editorRef.current) {
      const view = getEditorView(editorParentRef);
      editorRef.current = view;
      // setEditorView(view);

      const state = initState({
        lang,
        code,
        fontSize,
        // extionsions: extensions,
      });
      view.setState(state);

      return () => {
        view.destroy();
      };
    }

    return () => null;
  }, [editorRef, editorParentRef, code, fontSize, lang]);

  return editorParentRef;
};

export default useRocm;

==> react-readonly-codemirror6-1.1.1.tgz: package/index.jsx <==
import { EditorView, basicSetup } from 'codemirror';
import { EditorState } from '@codemirror/state';
import { oneDark } from '@codemirror/theme-one-dark';
import { useEffect, useRef } from 'react';
import getLanguageExtension from './src/getLanguageExtension';

const noPasteExtension = EditorView.domEventHandlers({
  paste: (event) => {
    // Prevent the default paste action
    event.preventDefault();
    return true; // This indicates that the event has been handled
  },
});

function getEditorView(parent) {
  return new EditorView({
    parent: parent.current,
  });
}

function initState({ code, lang }) {
  const language = getLanguageExtension(lang);

  return EditorState.create({
    doc: code,
    extensions: [
      noPasteExtension,
      basicSetup,
      oneDark,
      language,
      EditorView.editable.of(false),
      EditorView.lineWrapping,
    ],
  });
}

const useRocm = ({ code, lang, fontSize }) => {
  const editorParentRef = useRef(null);
  const editorRef = useRef(null);

  // Initilize view
  useEffect(() => {
    if (!editorRef.current) {
      const view = getEditorView(editorParentRef);
      view.dom.style.fontSize = `${fontSize}px`;
      editorRef.current = view;

      const state = initState({
        lang,
        code,
      });
      view.setState(state);

      return () => {
        view.destroy();
      };
    }

    return () => null;
  }, [editorRef, editorParentRef, code, fontSize, lang]);

  return editorParentRef;
};

export default useRocm;
